"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.tokenInfo = exports.token = exports.SubjectType = void 0;
const transform_error_1 = require("@wix/sdk-runtime/transform-error");
const rename_all_nested_keys_1 = require("@wix/sdk-runtime/rename-all-nested-keys");
const ambassadorWixIdentityOauthV1RefreshToken = __importStar(require("./identity-oauth-v1-refresh-token-oauth.http.js"));
var SubjectType;
(function (SubjectType) {
    /** unknown subject type */
    SubjectType["UNKNOWN"] = "UNKNOWN";
    /** user subject type */
    SubjectType["USER"] = "USER";
    /** visitor subject type */
    SubjectType["VISITOR"] = "VISITOR";
    /** member subject type */
    SubjectType["MEMBER"] = "MEMBER";
    /** app subject type */
    SubjectType["APP"] = "APP";
})(SubjectType || (exports.SubjectType = SubjectType = {}));
/**
 * Creates an access token.
 *
 *
 * The endpoint accepts raw HTTP requests. You must pass the request's body
 * parameters formatted as bytes in the raw HTTP request's `body` field,
 * following this template:
 * `{"grantType": "client_credentials", "client_id": "<APP_ID>", "client_secret": "<APP_SECRET_KEY>", "instance_id": "<INSTANCE_ID>"}`.
 *
 * When the call succeeds, Wix returns `{"statusCode": 200}` and the created access
 * token in the `body` field of the raw HTTP response.
 *
 * In case the call fails, Wix returns the relevant `4XX` error code in the raw
 * HTTP response's `statusCode` field and details
 * about the error in `body`. Error details follow the
 * [conventions of the Internet Engineering Task Force (IETF)](https://datatracker.ietf.org/doc/html/rfc6749#appendix-A.7).
 * @public
 * @fqn wix.identity.oauth2.v1.Oauth2Ng.Token
 */
async function token(options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        body: options?.body,
        pathParams: options?.pathParams,
        queryParams: options?.queryParams,
        headers: options?.headers,
        method: options?.method,
        rawPath: options?.rawPath,
        rawQuery: options?.rawQuery,
    });
    const reqOpts = ambassadorWixIdentityOauthV1RefreshToken.token(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                body: '$[0].body',
                pathParams: '$[0].pathParams',
                queryParams: '$[0].queryParams',
                headers: '$[0].headers',
                method: '$[0].method',
                rawPath: '$[0].rawPath',
                rawQuery: '$[0].rawQuery',
            },
            singleArgumentUnchanged: false,
        }, ['options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.token = token;
/**
 * Token Introspection Endpoint.
 * @public
 * @fqn wix.identity.oauth2.v1.Oauth2Ng.TokenInfo
 */
async function tokenInfo(options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        body: options?.body,
        pathParams: options?.pathParams,
        queryParams: options?.queryParams,
        headers: options?.headers,
        method: options?.method,
        rawPath: options?.rawPath,
        rawQuery: options?.rawQuery,
    });
    const reqOpts = ambassadorWixIdentityOauthV1RefreshToken.tokenInfo(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                body: '$[0].body',
                pathParams: '$[0].pathParams',
                queryParams: '$[0].queryParams',
                headers: '$[0].headers',
                method: '$[0].method',
                rawPath: '$[0].rawPath',
                rawQuery: '$[0].rawQuery',
            },
            singleArgumentUnchanged: false,
        }, ['options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.tokenInfo = tokenInfo;
//# sourceMappingURL=identity-oauth-v1-refresh-token-oauth.universal.js.map